@@ -1,5 +1,3 @@
-import json
-
 from django.http import HttpResponse
 from django.utils.decorators import method_decorator
 from django.views import generic
@@ -12,13 +10,9 @@ from .exceptions import PayeerValidationError, AlreadyPaid
 @method_decorator(csrf_exempt, name="dispatch")
 class NotifyView(generic.View):
     def post(self, request, *args, **kwargs):
-        try:
-            data = json.loads(request.body)
-        except json.JSONDecodeError:
-            return HttpResponse("JSON decode error", status=400)
         api = get_payeer_api()
         try:
-            result = api.notify(data)
+            result = api.notify(request.POST)
         except PayeerValidationError as exc:
             return HttpResponse(f"{exc.order_id}|error")
         except AlreadyPaid as exc:
